@@ -233,7 +233,7 @@ class Frame(object):
         self.data = frame_px_resampling(self.data, scale, imlib, interpolation,
                                         verbose)
 
-    def rotate(self, angle, imlib='opencv', interpolation='lanczos4', cxy=None):
+    def rotate(self, angle, imlib='vip-fft', interpolation='lanczos4', cxy=None):
         """ Rotating the image by a given ``angle``.
 
         Parameters
@@ -308,7 +308,7 @@ class Frame(object):
         """
         if self.fwhm is None:
             raise ValueError('FWHM has not been set')
-        return snr(self.data, source_xy, self.fwhm, False, plot, verbose)
+        return snr(self.data, source_xy, self.fwhm, False, None, plot, verbose)
 
     def stats(self, region='circle', radius=5, xy=None, annulus_inner_radius=0,
               annulus_width=5, source_xy=None, verbose=True, plot=True):
