@@ -2,6 +2,14 @@
 
 """
 Module with frame de-rotation routine for ADI.
+
+.. [LAR97]
+   | Larkin et al. 1997
+   | **Fast Fourier method for the accurate rotation of sampled images**
+   | *Optics Communications, Volume 154, Issue 1-3, pp. 99-106*
+   | `https://ui.adsabs.harvard.edu/abs/1997OptCo.139...99L
+     <https://ui.adsabs.harvard.edu/abs/1997OptCo.139...99L>`_
+
 """
 
 
@@ -45,7 +53,7 @@ def frame_rotate(array, angle, imlib='vip-fft', interpolation='lanczos4',
     imlib : {'opencv', 'skimage', 'vip-fft'}, str optional
         Library used for image transformations. Opencv is faster than
         Skimage or scipy.ndimage. 'vip-fft' corresponds to the FFT-based
-        rotation described in Larkin et al. (1997), and implemented in this
+        rotation method described in [LAR97]_, and implemented in this
         module. Best results are obtained with images without any sharp
         intensity change (i.e. no numerical mask). Edge-blending and/or
         zero-interpolation may help if sharp transitions are unavoidable.
@@ -81,9 +89,11 @@ def frame_rotate(array, angle, imlib='vip-fft', interpolation='lanczos4',
         with a gaussian filter. Slower but can significantly reduce ringing
         artefacts from Gibbs phenomenon, in particular if several consecutive
         rotations are involved in your image processing.
-        'noise': pad with small amplitude noise inferred from neighbours
-        'interp': interpolated from neighbouring pixels using Gaussian kernel.
-        'noise+interp': sum both components above at masked locations.
+        
+        - 'noise': pad with small amplitude noise inferred from neighbours
+        - 'interp': interpolated from neighbouring pixels using Gaussian kernel.
+        - 'noise+interp': sum both components above at masked locations.
+        
         Original mask will be placed back after rotation.
     interp_zeros: bool, opt
         [only used if edge_blend is not None]
@@ -124,6 +134,7 @@ def frame_rotate(array, angle, imlib='vip-fft', interpolation='lanczos4',
             _, med, stddev = sigma_clipped_stats(array_nan, sigma=1.5,
                                                  cenfunc=np.nanmedian,
                                                  stdfunc=np.nanstd)
+
         # pad and interpolate, about 1.2x original size
         if imlib == 'vip-fft':
             fac = 1.5
@@ -513,19 +524,9 @@ def _define_annuli(angle_list, ann, n_annuli, fwhm, radius_int, annulus_width,
 
 
 def rotate_fft(array, angle):
-    """ Rotates a frame or 2D array using Fourier transform phases:
-        Rotation = 3 consecutive lin. shears = 3 consecutive FFT phase shifts
-        See details in Larkin et al. (1997) and Hagelberg et al. (2016).
-        Note: this is significantly slower than interpolation methods
-        (e.g. opencv/lanczos4 or ndimage), but preserves the flux better
-        (by construction it preserves the total power). It is more prone to
-        large-scale Gibbs artefacts, so make sure no sharp edge is present in
-        the image to be rotated.
-
-        ! Warning: if input frame has even dimensions, the center of rotation
-        will NOT be between the 4 central pixels, instead it will be on the top
-        right of those 4 pixels. Make sure your images are centered with
-        respect to that pixel before rotation.
+    """ Rotates a frame or 2D array using Fourier transform phases.
+    Rotation is equivalent to 3 consecutive linear shears, or 3 consecutive 1D
+    FFT phase shifts. See details in [LAR97]_. 
 
     Parameters
     ----------
@@ -538,6 +539,20 @@ def rotate_fft(array, angle):
     -------
     array_out : numpy ndarray
         Resulting frame.
+        
+    Note
+    ----
+    This method is slower than interpolation methods (e.g. opencv/lanczos4 or 
+    ndimage), but preserves the flux better (by construction it preserves the 
+    total power). It is more prone to large-scale Gibbs artefacts, so make sure 
+    no sharp edge nor bad pixels are present in the image to be rotated.
+    
+    Note
+    ----
+    Warning: if input frame has even dimensions, the center of rotation
+    will NOT be between the 4 central pixels, instead it will be on the top
+    right of those 4 pixels. Make sure your images are centered with
+    respect to that pixel before rotation.
 
     """
     y_ori, x_ori = array.shape
@@ -576,7 +591,7 @@ def rotate_fft(array, angle):
     arr_y = arr_xy[0]-cy
     arr_x = arr_xy[1]-cx
 
-    # TODO: FFT padding not currently working properly. Only option '0' works.
+    # TODO: make FFT padding work for other option than '0'.
     s_x = _fft_shear(array_in, arr_x, a, ax=1, pad=0)
     s_xy = _fft_shear(s_x, arr_y, b, ax=0, pad=0)
     s_xyx = _fft_shear(s_xy, arr_x, a, ax=1, pad=0)
