@@ -67,7 +67,7 @@ from .cosmetics import cube_crop_frames, frame_crop
 
 def frame_shift(array, shift_y, shift_x, imlib='vip-fft',
                 interpolation='lanczos4', border_mode='reflect'):
-    """ Shifts a 2D array by shift_y, shift_x. Boundaries are filled with zeros.
+    """ Shifts a 2D array by shift_y, shift_x.
 
     Parameters
     ----------
@@ -95,7 +95,7 @@ def frame_shift(array, shift_y, shift_x, imlib='vip-fft',
         Opencv and 'biquartic' for Scipy.ndimage.
     border_mode : {'reflect', 'nearest', 'constant', 'mirror', 'wrap'}
         For 'opencv' and 'ndimage-interp', points outside the boundaries of the
-        input are filled according to tge value of this parameter.
+        input are filled according to the value of this parameter.
         With 'reflect', the input is extended by reflecting about the edge of
         the last pixel. With 'nearest', the input is extended by replicating the
         last pixel. With 'constant', the input is extended by filling all values
@@ -256,8 +256,8 @@ def frame_shift(array, shift_y, shift_x, imlib='vip-fft',
     return array_shifted
 
 
-def cube_shift(cube, shift_y, shift_x, imlib='vip-fft',
-               interpolation='lanczos4', border_mode='reflect'):
+def cube_shift(cube, shift_y, shift_x, imlib='vip-fft', 
+               interpolation='lanczos4', border_mode='reflect', nproc=None):
     """ Shifts the X-Y coordinates of a cube or 3D array by x and y values.
 
     Parameters
@@ -273,6 +273,9 @@ def cube_shift(cube, shift_y, shift_x, imlib='vip-fft',
         See the documentation of the ``vip_hci.preproc.frame_shift`` function.
     border_mode : str, optional
         See the documentation of the ``vip_hci.preproc.frame_shift`` function.
+    nproc: int or None, optional
+        Number of CPUs to use for multiprocessing. If None, will be 
+        automatically set to half the number of available CPUs.
 
     Returns
     -------
@@ -283,15 +286,24 @@ def cube_shift(cube, shift_y, shift_x, imlib='vip-fft',
     check_array(cube, dim=3)
 
     nfr = cube.shape[0]
-    cube_out = np.zeros_like(cube)
-    if isinstance(shift_x, (int, float)):
-        shift_x = np.ones((nfr)) * shift_x
-    if isinstance(shift_y, (int, float)):
-        shift_y = np.ones((nfr)) * shift_y
+    if np.isscalar(shift_x):
+        shift_x = np.ones([nfr]) * shift_x
+    if np.isscalar(shift_y):
+        shift_y = np.ones([nfr]) * shift_y
+
+    if nproc is None:
+        nproc = cpu_count()//2
+        
+    if nproc == 1:
+        cube_out = np.zeros_like(cube)
+        for i in range(cube.shape[0]):
+            cube_out[i] = frame_shift(cube[i], shift_y[i], shift_x[i], imlib,
+                                      interpolation, border_mode)
+    elif nproc > 1:
+        res = pool_map(nproc, frame_shift, iterable(cube), iterable(shift_y),
+                       iterable(shift_x), imlib, interpolation, border_mode)
+        cube_out = np.array(res)
 
-    for i in range(cube.shape[0]):
-        cube_out[i] = frame_shift(cube[i], shift_y[i], shift_x[i], imlib,
-                                  interpolation, border_mode)
     return cube_out
 
 
@@ -1082,7 +1094,7 @@ def cube_recenter_dft_upsampling(array, center_fr1=None, negative=False,
                                  fwhm=4, subi_size=None, upsample_factor=100,
                                  imlib='vip-fft', interpolation='lanczos4',
                                  mask=None, border_mode='reflect',
-                                 full_output=False, verbose=True, nproc=1,
+                                 full_output=False, verbose=True, nproc=None,
                                  save_shifts=False, debug=False, plot=True):
     """ Recenters a cube of frames using the DFT upsampling method as proposed 
     in [GUI08]_ and implemented in the ``register_translation`` function from 
@@ -1176,8 +1188,8 @@ def cube_recenter_dft_upsampling(array, center_fr1=None, negative=False,
     n_frames, sizey, sizex = array.shape
     if subi_size is not None:
         if center_fr1 is None:
-            print('`cx_1` or `cy_1` not be provided')
-            print('Using the coordinated of the 1st frame center for '
+            print('`cx_1` or `cy_1` not provided')
+            print('Using the coordinates of the 1st frame center for '
                   'the Gaussian 2d fit')
             cy_1, cx_1 = frame_center(array[0])
         else:
@@ -1206,6 +1218,9 @@ def cube_recenter_dft_upsampling(array, center_fr1=None, negative=False,
 
     # Finding the shifts with DFT upsampling of each frame wrt the first
 
+    if nproc is None:
+        nproc = cpu_count() // 2  # Hyper-threading doubles the # of cores
+
     if nproc == 1:
         for i in Progressbar(range(1, n_frames),
                              desc="frames", verbose=verbose):
@@ -1238,7 +1253,7 @@ def cube_recenter_dft_upsampling(array, center_fr1=None, negative=False,
         x[:] += cx - x1
         y[:] += cy - y1
         array_rec = cube_shift(array, shift_y=y, shift_x=x, imlib=imlib,
-                               interpolation=interpolation)
+                               interpolation=interpolation, nproc=nproc)
         if verbose:
             msg = "Shift for first frame X,Y=({:.3f}, {:.3f})"
             print(msg.format(x[0], y[0]))
@@ -1305,7 +1320,7 @@ def _shift_dft(array_rec, array, frnum, upsample_factor, mask, interpolation,
 
 
 def cube_recenter_2dfit(array, xy=None, fwhm=4, subi_size=5, model='gauss',
-                        nproc=1, imlib='vip-fft', interpolation='lanczos4',
+                        nproc=None, imlib='vip-fft', interpolation='lanczos4',
                         offset=None, negative=False, threshold=False,
                         sigfactor=2, fix_neg=False, params_2g=None,
                         border_mode='reflect', save_shifts=False,
@@ -1461,7 +1476,8 @@ def cube_recenter_2dfit(array, xy=None, fwhm=4, subi_size=5, model='gauss',
 
     if nproc == 1:
         res = []
-        print('2d {}-fitting'.format(model))
+        if verbose:
+            print('2d {}-fitting'.format(model))
         for i in Progressbar(range(n_frames), desc="frames", verbose=verbose):
             if model == "2gauss":
                 args = [array, i, subi_size, pos_y, pos_x, debug, fwhm[i],
@@ -1651,7 +1667,7 @@ def cube_recenter_via_speckles(cube_sci, cube_ref=None, alignment_iter=5,
                                fit_type='gaus', negative=True, crop=True,
                                subframesize=21, mask=None, imlib='vip-fft',
                                interpolation='lanczos4', border_mode='reflect',
-                               plot=True, full_output=False):
+                               plot=True, full_output=False, nproc=None):
     """ Registers frames based on the median speckle pattern. Optionally centers
     based on the position of the vortex null in the median frame. Images are
     filtered to isolate speckle spatial frequencies.
@@ -1710,6 +1726,7 @@ def cube_recenter_via_speckles(cube_sci, cube_ref=None, alignment_iter=5,
     full_output: bool, optional
         Whether to return more variables, useful for debugging.
 
+
     Returns
     -------
     cube_reg_sci : numpy 3d ndarray
@@ -1732,6 +1749,9 @@ def cube_recenter_via_speckles(cube_sci, cube_ref=None, alignment_iter=5,
     n, y, x = cube_sci.shape
     check_array(cube_sci, dim=3)
 
+    if nproc is None:
+        nproc = cpu_count()//2
+
     if recenter_median and fit_type not in {'gaus', 'ann'}:
         raise TypeError("fit type not recognized. Should be 'ann' or 'gaus'")
 
@@ -1849,7 +1869,7 @@ def cube_recenter_via_speckles(cube_sci, cube_ref=None, alignment_iter=5,
                                            subi_size=None, full_output=True,
                                            verbose=False, plot=False,
                                            mask=mask_tmp, imlib=imlib,
-                                           interpolation=interpolation)
+                                           interpolation=interpolation, nproc=nproc)
         _, y_shift, x_shift = res
         sqsum_shifts = np.sum(np.sqrt(y_shift ** 2 + x_shift ** 2))
         print('Square sum of shift vecs: ' + str(sqsum_shifts))
@@ -1918,7 +1938,7 @@ def cube_recenter_via_speckles(cube_sci, cube_ref=None, alignment_iter=5,
 def _fit_2dannulus(array, fwhm=4, crop=False, cent=None, cropsize=15,
                    hole_rad=0.5, sampl_cen=0.1, sampl_rad=None, ann_width=0.5,
                    unc_in=2.):
-    """Finds the center the center of a donut-shape signal (e.g. a coronagraphic
+    """Finds the center of a donut-shape signal (e.g. a coronagraphic
     PSF) by fitting an annulus, using a grid of positions for the center and
     radius of the annulus. The best fit is found by maximizing the mean flux
     measured in the annular mask. Requires the image to be already roughly
