@@ -1,14 +1,14 @@
 """
 Subpackage ``psfsub`` contains a large number of stellar PSF modelling +
 subtraction algorithms. The following methods have been implemented:
-- *median ADI/SDI* (Marois et al. 2006).
+- *median ADI/SDI* [MAR06]_ / [SPA02]_ / [THA07]_.
 - *frame differencing*.
-- a simplified version of *LOCI* (Lafreniere et al. 2007)
-- different flavours of *PCA* (Soummer et al. 2012 and Amara et al. 2012)
+- a simplified version of *LOCI* [LAF07]_
+- different flavours of *PCA* [AMA12]_ / [SOU12]_
 working in full-frame, incremental and annular mode, including improvements,
 speed tricks, compatibility with ADI/RDI/SDI datasets and datasets too large to
 fit in memory.
-- full-frame and annular versions of *NMF*.
+- full-frame and annular versions of *NMF* [LEE99]_ / [GOM17]_.
 """
 
 from .pca_fullfr import *
