@@ -81,7 +81,7 @@ def create_synth_psf(model='gauss', shape=(9, 9), amplitude=1, x_mean=None,
 
     Note
     ----
-    More information can be found a the following links: 
+    More information can be found at the following links:
         http://docs.astropy.org/en/stable/api/astropy.modeling.functional_models.Gaussian2D.html
         http://docs.astropy.org/en/stable/api/astropy.modeling.functional_models.Moffat2D.html
         http://docs.astropy.org/en/stable/api/astropy.modeling.functional_models.AiryDisk2D.html
@@ -211,7 +211,8 @@ def fit_2dgaussian(array, crop=False, cent=None, cropsize=15, fwhmx=4, fwhmy=4,
 
         imside = array.shape[0]
         psf_subimage, suby, subx = get_square(array, min(cropsize, imside),
-                                              ceny, cenx, position=True)
+                                              ceny, cenx, position=True, 
+                                              verbose=False)
     else:
         psf_subimage = array.copy()
 
